@@ -931,20 +931,17 @@ class Font:
         wws_family_name = family_name
         wws_subfamily_name = style_name
 
-        # family name, subfamily name and full name - fix legacy name records 1 and 2
+        # family name and subfamily name
         subfamily_names = ["regular", "italic", "bold", "bold italic"]
-        subfamily_name = style_name
-        style_name_lower = style_name.lower()
-        if style_name_lower not in subfamily_names:
-            subfamily_name = (
-                "Italic" if style_name_lower.endswith(" italic") else "Regular"
-            )
+        subfamily_name = style_name.lower()
+        if subfamily_name not in subfamily_names:
+            # fix legacy name records 1 and 2
             family_name_suffix = re.sub(
-                r"\ italic$", "", subfamily_name, flags=re.IGNORECASE
+                r"\ italic$", "", style_name, flags=re.IGNORECASE
             )
-            assert family_name_suffix
-            family_name = f"{typographic_family_name} {family_name_suffix}"
-
+            if family_name_suffix:
+                family_name = f"{typographic_family_name} {family_name_suffix}"
+            subfamily_name = subfamily_names["italic" in subfamily_name]
         subfamily_name = subfamily_name.title()
 
         # full name
